fortify.lm: Supplement the data fitted to a linear model with model fit...

Description Usage Arguments Details Value Examples

View source: R/fortify-lm.r

Description

Supplement the data fitted to a linear model with model fit statistics.

Usage

1
fortify.lm(model, data=model$model, ...)

Arguments

model

linear model

data

data set, defaults to data used to fit model

...

not used by this method

Details

If you have missing values in your model data, you may need to refit the model with na.action = na.exclude.

The following statistics will be added to the data frame:

Value

The original data with extra columns:

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
mod <- lm(mpg ~ wt, data = mtcars)
head(fortify(mod))
head(fortify(mod, mtcars))

plot(mod, which = 1)
qplot(.fitted, .resid, data = mod) + geom_hline() + geom_smooth(se = FALSE)
qplot(.fitted, .stdresid, data = mod) + geom_hline() + 
geom_smooth(se = FALSE)
qplot(.fitted, .stdresid, data = fortify(mod, mtcars), 
colour = factor(cyl))
qplot(mpg, .stdresid, data = fortify(mod, mtcars), colour = factor(cyl))

plot(mod, which = 2)
# qplot(sample =.stdresid, data = mod, stat = "qq") + geom_abline()

plot(mod, which = 3)
qplot(.fitted, sqrt(abs(.stdresid)), data = mod) + geom_smooth(se = FALSE)

plot(mod, which = 4)
qplot(seq_along(.cooksd), .cooksd, data = mod, geom = "bar",
stat="identity")

plot(mod, which = 5)
qplot(.hat, .stdresid, data = mod) + geom_smooth(se = FALSE)
ggplot(mod, aes(.hat, .stdresid)) + 
geom_vline(size = 2, colour = "white", xintercept = 0) +
geom_hline(size = 2, colour = "white", yintercept = 0) +
geom_point() + geom_smooth(se = FALSE)

qplot(.hat, .stdresid, data = mod, size = .cooksd) + 
geom_smooth(se = FALSE, size = 0.5)

plot(mod, which = 6)
ggplot(mod, aes(.hat, .cooksd, data = mod)) + 
geom_vline(colour = NA) + 
geom_abline(slope = seq(0, 3, by = 0.5), colour = "white") +
geom_smooth(se = FALSE) + 
geom_point()
qplot(.hat, .cooksd, size = .cooksd / .hat, data = mod) + scale_area()

hadley/fortify documentation built on May 17, 2019, 10:15 a.m.